# Cycling Dynamics
Cycling (Bicycling) models of motion, air drag, rolling resistance, power calculations.

This project is in activly being developed and has incomplete methods, models, stats and functions.


[![PyPI - Version](https://img.shields.io/pypi/v/cycling-dynamics.svg)](https://pypi.org/project/cycling-dynamics)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/cycling-dynamics.svg)](https://pypi.org/project/cycling-dynamics)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install cycling-dynamics
```

## License

`cycling-dynamics` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
